
(* The type of tokens. *)

type token = 
  | WITH
  | WHILE
  | WHEN
  | VIRTUAL
  | VAL
  | UNDERSCORE
  | UIDENT of (string)
  | TYPE
  | TRY
  | TRUE
  | TO
  | TILDE
  | THEN
  | SWITCH
  | STRUCT
  | STRING of (string * string option * string option)
  | STAR
  | SLASHGREATER
  | SIG
  | SHARPOP of (string)
  | SHARPEQUAL
  | SHARP
  | SEMISEMI
  | SEMI
  | RPAREN
  | REC
  | RBRACKET
  | RBRACE
  | QUOTE
  | QUESTION
  | PUB
  | PRI
  | PREFIXOP of (string)
  | POSTFIXOP of (string)
  | PLUSEQ
  | PLUSDOT
  | PLUS
  | PERCENT
  | OR
  | OPEN
  | OF
  | OBJECT
  | NONREC
  | NEW
  | NATIVEINT of (nativeint)
  | MUTABLE
  | MODULE
  | MINUSGREATER
  | MINUSDOT
  | MINUS
  | LPAREN
  | LIDENT of (string)
  | LETOP of (string)
  | LET
  | LESSUIDENT of (string)
  | LESSSLASHIDENTGREATER of (string)
  | LESSSLASHGREATER
  | LESSIDENT of (string)
  | LESSGREATER
  | LESSDOTDOTGREATER
  | LESS
  | LBRACKETPERCENTPERCENT
  | LBRACKETPERCENT
  | LBRACKETLESS
  | LBRACKETGREATER
  | LBRACKETBAR
  | LBRACKETAT
  | LBRACKET
  | LBRACELESS
  | LBRACE
  | LAZY
  | INT of (string * char option)
  | INITIALIZER
  | INHERIT
  | INFIXOP4 of (string)
  | INFIXOP3 of (string)
  | INFIXOP2 of (string)
  | INFIXOP1 of (string)
  | INFIXOP0 of (string)
  | INCLUDE
  | IN
  | IF
  | GREATERRBRACE
  | GREATERDOTDOTDOT
  | GREATER
  | FUNCTOR
  | FUNCTION
  | FUN
  | FOR
  | FLOAT of (string * char option)
  | FALSE
  | EXTERNAL
  | EXCEPTION
  | ES6_FUN
  | EQUALGREATER
  | EQUAL
  | EOL
  | EOF
  | END
  | ELSE
  | DOWNTO
  | DOTDOTDOT
  | DOTDOT
  | DOT
  | DONE
  | DOCSTRING of (string)
  | DO
  | CONSTRAINT
  | COMMENT of (string * Location.t)
  | COMMA
  | COLONGREATER
  | COLONEQUAL
  | COLONCOLON
  | COLON
  | CLASS
  | CHAR of (char)
  | BEGIN
  | BARRBRACKET
  | BARBAR
  | BAR
  | BANG
  | BACKQUOTE
  | ASSERT
  | AS
  | ANDOP of (string)
  | AND
  | AMPERSAND
  | AMPERAMPER

(* This exception is raised by the monolithic API functions. *)

exception Error

(* The monolithic API. *)

val use_file: (Lexing.lexbuf -> token) -> Lexing.lexbuf -> (Reason_migrate_parsetree.Ast_411.Parsetree.toplevel_phrase list)

val toplevel_phrase: (Lexing.lexbuf -> token) -> Lexing.lexbuf -> (Reason_migrate_parsetree.Ast_411.Parsetree.toplevel_phrase)

val parse_pattern: (Lexing.lexbuf -> token) -> Lexing.lexbuf -> (Reason_migrate_parsetree.Ast_411.Parsetree.pattern)

val parse_expression: (Lexing.lexbuf -> token) -> Lexing.lexbuf -> (Reason_migrate_parsetree.Ast_411.Parsetree.expression)

val parse_core_type: (Lexing.lexbuf -> token) -> Lexing.lexbuf -> (Reason_migrate_parsetree.Ast_411.Parsetree.core_type)

val interface: (Lexing.lexbuf -> token) -> Lexing.lexbuf -> (Reason_migrate_parsetree.Ast_411.Parsetree.signature)

val implementation: (Lexing.lexbuf -> token) -> Lexing.lexbuf -> (Reason_migrate_parsetree.Ast_411.Parsetree.structure)

module MenhirInterpreter : sig
  
  (* The incremental API. *)
  
  include MenhirLib.IncrementalEngine.INCREMENTAL_ENGINE
    with type token = token
  
  (* The indexed type of terminal symbols. *)
  
  type _ terminal = 
    | T_error : unit terminal
    | T_WITH : unit terminal
    | T_WHILE : unit terminal
    | T_WHEN : unit terminal
    | T_VIRTUAL : unit terminal
    | T_VAL : unit terminal
    | T_UNDERSCORE : unit terminal
    | T_UIDENT : (string) terminal
    | T_TYPE : unit terminal
    | T_TRY : unit terminal
    | T_TRUE : unit terminal
    | T_TO : unit terminal
    | T_TILDE : unit terminal
    | T_THEN : unit terminal
    | T_SWITCH : unit terminal
    | T_STRUCT : unit terminal
    | T_STRING : (string * string option * string option) terminal
    | T_STAR : unit terminal
    | T_SLASHGREATER : unit terminal
    | T_SIG : unit terminal
    | T_SHARPOP : (string) terminal
    | T_SHARPEQUAL : unit terminal
    | T_SHARP : unit terminal
    | T_SEMISEMI : unit terminal
    | T_SEMI : unit terminal
    | T_RPAREN : unit terminal
    | T_REC : unit terminal
    | T_RBRACKET : unit terminal
    | T_RBRACE : unit terminal
    | T_QUOTE : unit terminal
    | T_QUESTION : unit terminal
    | T_PUB : unit terminal
    | T_PRI : unit terminal
    | T_PREFIXOP : (string) terminal
    | T_POSTFIXOP : (string) terminal
    | T_PLUSEQ : unit terminal
    | T_PLUSDOT : unit terminal
    | T_PLUS : unit terminal
    | T_PERCENT : unit terminal
    | T_OR : unit terminal
    | T_OPEN : unit terminal
    | T_OF : unit terminal
    | T_OBJECT : unit terminal
    | T_NONREC : unit terminal
    | T_NEW : unit terminal
    | T_NATIVEINT : (nativeint) terminal
    | T_MUTABLE : unit terminal
    | T_MODULE : unit terminal
    | T_MINUSGREATER : unit terminal
    | T_MINUSDOT : unit terminal
    | T_MINUS : unit terminal
    | T_LPAREN : unit terminal
    | T_LIDENT : (string) terminal
    | T_LETOP : (string) terminal
    | T_LET : unit terminal
    | T_LESSUIDENT : (string) terminal
    | T_LESSSLASHIDENTGREATER : (string) terminal
    | T_LESSSLASHGREATER : unit terminal
    | T_LESSIDENT : (string) terminal
    | T_LESSGREATER : unit terminal
    | T_LESSDOTDOTGREATER : unit terminal
    | T_LESS : unit terminal
    | T_LBRACKETPERCENTPERCENT : unit terminal
    | T_LBRACKETPERCENT : unit terminal
    | T_LBRACKETLESS : unit terminal
    | T_LBRACKETGREATER : unit terminal
    | T_LBRACKETBAR : unit terminal
    | T_LBRACKETAT : unit terminal
    | T_LBRACKET : unit terminal
    | T_LBRACELESS : unit terminal
    | T_LBRACE : unit terminal
    | T_LAZY : unit terminal
    | T_INT : (string * char option) terminal
    | T_INITIALIZER : unit terminal
    | T_INHERIT : unit terminal
    | T_INFIXOP4 : (string) terminal
    | T_INFIXOP3 : (string) terminal
    | T_INFIXOP2 : (string) terminal
    | T_INFIXOP1 : (string) terminal
    | T_INFIXOP0 : (string) terminal
    | T_INCLUDE : unit terminal
    | T_IN : unit terminal
    | T_IF : unit terminal
    | T_GREATERRBRACE : unit terminal
    | T_GREATERDOTDOTDOT : unit terminal
    | T_GREATER : unit terminal
    | T_FUNCTOR : unit terminal
    | T_FUNCTION : unit terminal
    | T_FUN : unit terminal
    | T_FOR : unit terminal
    | T_FLOAT : (string * char option) terminal
    | T_FALSE : unit terminal
    | T_EXTERNAL : unit terminal
    | T_EXCEPTION : unit terminal
    | T_ES6_FUN : unit terminal
    | T_EQUALGREATER : unit terminal
    | T_EQUAL : unit terminal
    | T_EOL : unit terminal
    | T_EOF : unit terminal
    | T_END : unit terminal
    | T_ELSE : unit terminal
    | T_DOWNTO : unit terminal
    | T_DOTDOTDOT : unit terminal
    | T_DOTDOT : unit terminal
    | T_DOT : unit terminal
    | T_DONE : unit terminal
    | T_DOCSTRING : (string) terminal
    | T_DO : unit terminal
    | T_CONSTRAINT : unit terminal
    | T_COMMENT : (string * Location.t) terminal
    | T_COMMA : unit terminal
    | T_COLONGREATER : unit terminal
    | T_COLONEQUAL : unit terminal
    | T_COLONCOLON : unit terminal
    | T_COLON : unit terminal
    | T_CLASS : unit terminal
    | T_CHAR : (char) terminal
    | T_BEGIN : unit terminal
    | T_BARRBRACKET : unit terminal
    | T_BARBAR : unit terminal
    | T_BAR : unit terminal
    | T_BANG : unit terminal
    | T_BACKQUOTE : unit terminal
    | T_ASSERT : unit terminal
    | T_AS : unit terminal
    | T_ANDOP : (string) terminal
    | T_AND : unit terminal
    | T_AMPERSAND : unit terminal
    | T_AMPERAMPER : unit terminal
  
  (* The indexed type of nonterminal symbols. *)
  
  type _ nonterminal = 
    | N_with_constraint : (Reason_migrate_parsetree.Ast_411.Parsetree.with_constraint) nonterminal
    | N_virtual_flag : (Reason_migrate_parsetree.Ast_411.Asttypes.virtual_flag) nonterminal
    | N_value_type : (string Location.loc *
  Reason_migrate_parsetree.Ast_411.Asttypes.mutable_flag *
  Reason_migrate_parsetree.Ast_411.Asttypes.virtual_flag *
  Reason_migrate_parsetree.Ast_411.Parsetree.core_type) nonterminal
    | N_value : (string Location.loc *
  Reason_migrate_parsetree.Ast_411.Asttypes.mutable_flag *
  Reason_migrate_parsetree.Ast_411.Parsetree.class_field_kind) nonterminal
    | N_val_longident : (Longident.t) nonterminal
    | N_val_ident : (string) nonterminal
    | N_use_file_no_mapper : (Reason_migrate_parsetree.Ast_411.Parsetree.toplevel_phrase list) nonterminal
    | N_use_file : (Reason_migrate_parsetree.Ast_411.Parsetree.toplevel_phrase list) nonterminal
    | N_unattributed_expr : (Reason_migrate_parsetree.Ast_411.Parsetree.expression) nonterminal
    | N_unattributed_core_type : (Reason_migrate_parsetree.Ast_411.Parsetree.core_type) nonterminal
    | N_type_variance : (Reason_migrate_parsetree.Ast_411.Asttypes.variance) nonterminal
    | N_type_variables_with_variance_comma_list : ((Reason_migrate_parsetree.Ast_411.Parsetree.core_type *
   Reason_migrate_parsetree.Ast_411.Asttypes.variance)
  list) nonterminal
    | N_type_variables_with_variance : ((Reason_migrate_parsetree.Ast_411.Parsetree.core_type *
   Reason_migrate_parsetree.Ast_411.Asttypes.variance)
  list) nonterminal
    | N_type_variable_with_variance : (Reason_migrate_parsetree.Ast_411.Parsetree.core_type *
  Reason_migrate_parsetree.Ast_411.Asttypes.variance) nonterminal
    | N_type_variable : (Reason_migrate_parsetree.Ast_411.Parsetree.core_type) nonterminal
    | N_type_subst_other_kind : (Reason_migrate_parsetree.Ast_411.Parsetree.type_kind *
  Reason_migrate_parsetree.Ast_411.Asttypes.private_flag *
  Reason_migrate_parsetree.Ast_411.Parsetree.core_type option) nonterminal
    | N_type_subst_kind : ((Reason_migrate_parsetree.Ast_411.Parsetree.type_kind *
   Reason_migrate_parsetree.Ast_411.Asttypes.private_flag *
   Reason_migrate_parsetree.Ast_411.Parsetree.core_type option) *
  (Reason_migrate_parsetree.Ast_411.Parsetree.core_type *
   Reason_migrate_parsetree.Ast_411.Parsetree.core_type * Warnings.loc)
  list * Lexing.position *
  Reason_migrate_parsetree.Ast_411.Parsetree.type_declaration list) nonterminal
    | N_type_subst_declarations : (Reason_migrate_parsetree.Ast_411.Parsetree.type_declaration list) nonterminal
    | N_type_subst_constructor_declarations_aux : (Reason_migrate_parsetree.Ast_411.Parsetree.constructor_declaration list *
  (Reason_migrate_parsetree.Ast_411.Parsetree.core_type *
   Reason_migrate_parsetree.Ast_411.Parsetree.core_type * Warnings.loc)
  list * Lexing.position *
  Reason_migrate_parsetree.Ast_411.Parsetree.type_declaration list) nonterminal
    | N_type_subst_constructor_declarations : (Reason_migrate_parsetree.Ast_411.Parsetree.constructor_declaration list *
  (Reason_migrate_parsetree.Ast_411.Parsetree.core_type *
   Reason_migrate_parsetree.Ast_411.Parsetree.core_type * Warnings.loc)
  list * Lexing.position *
  Reason_migrate_parsetree.Ast_411.Parsetree.type_declaration list) nonterminal
    | N_type_parameters : (Reason_migrate_parsetree.Ast_411.Parsetree.core_type list) nonterminal
    | N_type_parameter : (Reason_migrate_parsetree.Ast_411.Parsetree.core_type *
  Reason_migrate_parsetree.Ast_411.Asttypes.variance) nonterminal
    | N_type_other_kind : (Reason_migrate_parsetree.Ast_411.Parsetree.type_kind *
  Reason_migrate_parsetree.Ast_411.Asttypes.private_flag *
  Reason_migrate_parsetree.Ast_411.Parsetree.core_type option) nonterminal
    | N_type_longident : (Reason_migrate_parsetree__Migrate_parsetree_versions.OCaml_411.Ast.Ast_helper.lid) nonterminal
    | N_type_declarations : (Reason_migrate_parsetree.Ast_411.Asttypes.rec_flag *
  Reason_migrate_parsetree.Ast_411.Parsetree.type_declaration list) nonterminal
    | N_type_declaration_kind : ((Reason_migrate_parsetree.Ast_411.Parsetree.type_kind *
   Reason_migrate_parsetree.Ast_411.Asttypes.private_flag *
   Reason_migrate_parsetree.Ast_411.Parsetree.core_type option) *
  (Reason_migrate_parsetree.Ast_411.Parsetree.core_type *
   Reason_migrate_parsetree.Ast_411.Parsetree.core_type * Warnings.loc)
  list * Lexing.position *
  Reason_migrate_parsetree.Ast_411.Parsetree.type_declaration list) nonterminal
    | N_type_declaration_details : ((Reason_migrate_parsetree__Migrate_parsetree_versions.OCaml_411.Ast.Ast_helper.str *
   (Reason_migrate_parsetree.Ast_411.Parsetree.core_type *
    Reason_migrate_parsetree.Ast_411.Asttypes.variance)
   list *
   (Reason_migrate_parsetree.Ast_411.Parsetree.core_type *
    Reason_migrate_parsetree.Ast_411.Parsetree.core_type * Warnings.loc)
   list * Reason_migrate_parsetree.Ast_411.Parsetree.type_kind *
   Reason_migrate_parsetree.Ast_411.Asttypes.private_flag *
   Reason_migrate_parsetree.Ast_411.Parsetree.core_type option) *
  Lexing.position *
  Reason_migrate_parsetree.Ast_411.Parsetree.type_declaration list) nonterminal
    | N_type_constraint : (Reason_migrate_parsetree.Ast_411.Parsetree.core_type option *
  Reason_migrate_parsetree.Ast_411.Parsetree.core_type option) nonterminal
    | N_toplevel_phrase : (Reason_migrate_parsetree.Ast_411.Parsetree.toplevel_phrase) nonterminal
    | N_toplevel_directive : (Reason_migrate_parsetree.Ast_411.Parsetree.toplevel_phrase) nonterminal
    | N_tag_field : (Reason_migrate_parsetree.Ast_411.Parsetree.row_field) nonterminal
    | N_structure_item : (Reason_migrate_parsetree.OCaml_411.Ast.Parsetree.structure) nonterminal
    | N_structure : (Reason_migrate_parsetree.OCaml_411.Ast.Parsetree.structure) nonterminal
    | N_string_literal_labels : (Reason_migrate_parsetree.Ast_411.Parsetree.object_field list) nonterminal
    | N_string_literal_label : (Reason_migrate_parsetree.Ast_411.Parsetree.object_field) nonterminal
    | N_string_literal_exprs_maybe_punned : ((Longident.t Location.loc *
   Reason_migrate_parsetree.Ast_411.Parsetree.expression)
  list) nonterminal
    | N_string_literal_expr_maybe_punned_with_comma : (Longident.t Location.loc *
  Reason_migrate_parsetree.Ast_411.Parsetree.expression) nonterminal
    | N_string_literal_expr_maybe_punned : (Longident.t Location.loc *
  Reason_migrate_parsetree.Ast_411.Parsetree.expression) nonterminal
    | N_str_type_extension : (Reason_migrate_parsetree.Ast_411.Parsetree.type_extension) nonterminal
    | N_str_exception_declaration : (Reason_migrate_parsetree.Ast_411.Parsetree.extension_constructor) nonterminal
    | N_single_attr_id : (string) nonterminal
    | N_simple_pattern_not_ident_ : (Reason_migrate_parsetree.Ast_411.Parsetree.pattern) nonterminal
    | N_simple_pattern_not_ident : (Reason_migrate_parsetree.Ast_411.Parsetree.pattern) nonterminal
    | N_simple_pattern_ident : (Reason_migrate_parsetree.Ast_411.Parsetree.pattern) nonterminal
    | N_simple_pattern_direct_argument : (Reason_migrate_parsetree.Ast_411.Parsetree.pattern) nonterminal
    | N_simple_pattern : (Reason_migrate_parsetree.Ast_411.Parsetree.pattern) nonterminal
    | N_simple_module_type : (Reason_migrate_parsetree.Ast_411.Parsetree.module_type) nonterminal
    | N_simple_expr_template_constructor : (Reason_migrate_parsetree.Ast_411.Parsetree.expression) nonterminal
    | N_simple_expr_no_constructor : (Reason_migrate_parsetree.Ast_411.Parsetree.expression) nonterminal
    | N_simple_expr_no_call : (Reason_migrate_parsetree.Ast_411.Parsetree.expression) nonterminal
    | N_simple_expr_direct_argument : (Reason_migrate_parsetree.Ast_411.Parsetree.expression) nonterminal
    | N_simple_expr_call : (Reason_migrate_parsetree.Ast_411.Parsetree.expression *
  (Reason_migrate_parsetree.Ast_411.Asttypes.arg_label *
   Reason_migrate_parsetree.Ast_411.Parsetree.expression)
  list) nonterminal
    | N_signed_constant : (Reason_migrate_parsetree__Migrate_parsetree_versions.OCaml_411.Ast.Ast_helper.attrs *
  Reason_migrate_parsetree.Ast_411.Parsetree.constant) nonterminal
    | N_signature_items : (Reason_migrate_parsetree.OCaml_411.Ast.Parsetree.signature) nonterminal
    | N_signature_item : (Reason_migrate_parsetree.Ast_411.Parsetree.signature_item_desc) nonterminal
    | N_signature : (Reason_migrate_parsetree.OCaml_411.Ast.Parsetree.signature) nonterminal
    | N_sig_type_extension : (Reason_migrate_parsetree.Ast_411.Parsetree.type_extension) nonterminal
    | N_sig_exception_declaration : (Reason_migrate_parsetree.Ast_411.Parsetree.type_exception) nonterminal
    | N_seq_expr_no_seq : (Reason_migrate_parsetree.Ast_411.Parsetree.expression) nonterminal
    | N_seq_expr : (Reason_migrate_parsetree.Ast_411.Parsetree.expression) nonterminal
    | N_separated_nonempty_list_AMPERSAND_non_arrowed_simple_core_types_ : (Reason_migrate_parsetree.Ast_411.Parsetree.core_type list) nonterminal
    | N_row_field_list : (Reason_migrate_parsetree.Ast_411.Parsetree.row_field list) nonterminal
    | N_row_field : (Reason_migrate_parsetree.Ast_411.Parsetree.row_field) nonterminal
    | N_record_label_declaration : (Reason_migrate_parsetree.Ast_411.Parsetree.label_declaration) nonterminal
    | N_record_expr_with_string_keys : (Reason_migrate_parsetree.Ast_411.Parsetree.expression option *
  (Longident.t Location.loc *
   Reason_migrate_parsetree.Ast_411.Parsetree.expression)
  list) nonterminal
    | N_record_expr : (Reason_migrate_parsetree.Ast_411.Parsetree.expression option *
  (Longident.t Location.loc *
   Reason_migrate_parsetree.Ast_411.Parsetree.expression)
  list) nonterminal
    | N_record_declaration : (Reason_migrate_parsetree.Ast_411.Parsetree.label_declaration list) nonterminal
    | N_rec_flag : (Reason_migrate_parsetree.Ast_411.Asttypes.rec_flag) nonterminal
    | N_protected_type : (Reason_migrate_parsetree.Ast_411.Parsetree.core_type) nonterminal
    | N_primitive_declaration : (string list) nonterminal
    | N_poly_type : (Reason_migrate_parsetree.Ast_411.Parsetree.core_type) nonterminal
    | N_payload : (Reason_migrate_parsetree.Ast_411.Parsetree.payload) nonterminal
    | N_pattern_without_or : (Reason_migrate_parsetree.Ast_411.Parsetree.pattern) nonterminal
    | N_pattern_optional_constraint : (Reason_migrate_parsetree.Ast_411.Parsetree.pattern) nonterminal
    | N_pattern_constructor_argument : (Reason_migrate_parsetree.Ast_411.Parsetree.pattern list) nonterminal
    | N_pattern_comma_list_extension : (Reason_migrate_parsetree.Ast_411.Parsetree.pattern list *
  Reason_migrate_parsetree.Ast_411.Parsetree.pattern option) nonterminal
    | N_pattern : (Reason_migrate_parsetree.Ast_411.Parsetree.pattern) nonterminal
    | N_parse_pattern : (Reason_migrate_parsetree.Ast_411.Parsetree.pattern) nonterminal
    | N_parse_expression : (Reason_migrate_parsetree.Ast_411.Parsetree.expression) nonterminal
    | N_parse_core_type : (Reason_migrate_parsetree.Ast_411.Parsetree.core_type) nonterminal
    | N_parenthesized_expr : (Reason_migrate_parsetree.Ast_411.Parsetree.expression) nonterminal
    | N_package_type : (Reason_migrate_parsetree.Ast_411.Parsetree.core_type) nonterminal
    | N_override_flag : (Reason_migrate_parsetree.Ast_411.Asttypes.override_flag) nonterminal
    | N_optional_expr_extension : (Reason_migrate_parsetree.Ast_411.Parsetree.expression ->
  Reason_migrate_parsetree.Ast_411.Parsetree.expression) nonterminal
    | N_optional : (string -> Reason_migrate_parsetree.Ast_411.Asttypes.arg_label) nonterminal
    | N_option_type_constraint_ : ((Reason_migrate_parsetree.Ast_411.Parsetree.core_type option *
   Reason_migrate_parsetree.Ast_411.Parsetree.core_type option)
  option) nonterminal
    | N_option_preceded_WHEN_expr__ : (Reason_migrate_parsetree.Ast_411.Parsetree.expression option) nonterminal
    | N_option_preceded_COLONGREATER_core_type__ : (Reason_migrate_parsetree.Ast_411.Parsetree.core_type option) nonterminal
    | N_option_preceded_COLON_simple_module_type__ : (Reason_migrate_parsetree.Ast_411.Parsetree.module_type option) nonterminal
    | N_option_preceded_COLON_poly_type__ : (Reason_migrate_parsetree.Ast_411.Parsetree.core_type option) nonterminal
    | N_option_preceded_COLON_non_arrowed_core_type__ : (Reason_migrate_parsetree.Ast_411.Parsetree.core_type option) nonterminal
    | N_option_preceded_COLON_expr__ : (Reason_migrate_parsetree.Ast_411.Parsetree.expression option) nonterminal
    | N_option_preceded_COLON_core_type__ : (Reason_migrate_parsetree.Ast_411.Parsetree.core_type option) nonterminal
    | N_option_preceded_COLON_class_constructor_type__ : (Reason_migrate_parsetree.Ast_411.Parsetree.class_type option) nonterminal
    | N_option_item_extension_sugar_ : ((Reason_migrate_parsetree__Migrate_parsetree_versions.OCaml_411.Ast.Ast_helper.attrs *
   string Location.loc)
  option) nonterminal
    | N_option_constructor_arguments_ : (Reason_migrate_parsetree.Ast_411.Parsetree.constructor_arguments option) nonterminal
    | N_option_as_loc_preceded_AS_LIDENT___ : (string Location.loc option) nonterminal
    | N_option_SEMI_ : (unit option) nonterminal
    | N_option_OF_ : (unit option) nonterminal
    | N_option_MODULE_ : (unit option) nonterminal
    | N_option_LET_ : (unit option) nonterminal
    | N_option_DOTDOTDOT_ : (unit option) nonterminal
    | N_option_DOT_ : (unit option) nonterminal
    | N_option_COMMA_ : (unit option) nonterminal
    | N_opt_LET_MODULE_ident : (Reason_migrate_parsetree__Migrate_parsetree_versions.OCaml_411.Ast.Ast_helper.str_opt) nonterminal
    | N_opt_LET_MODULE_REC_ident : (Reason_migrate_parsetree__Migrate_parsetree_versions.OCaml_411.Ast.Ast_helper.str_opt) nonterminal
    | N_opt_LET_MODULE : (unit) nonterminal
    | N_operator : (string) nonterminal
    | N_open_description : (Reason_migrate_parsetree.OCaml_411.Ast.Parsetree.open_description) nonterminal
    | N_open_declaration : (Reason_migrate_parsetree.Ast_411.Parsetree.module_expr
  Reason_migrate_parsetree.Ast_411.Parsetree.open_infos) nonterminal
    | N_object_record_type : (Reason_migrate_parsetree.Ast_411.Parsetree.core_type) nonterminal
    | N_object_label_declarations : (Reason_migrate_parsetree.Ast_411.Parsetree.object_field list) nonterminal
    | N_object_label_declaration : (Reason_migrate_parsetree.Ast_411.Parsetree.object_field) nonterminal
    | N_object_body_class_fields : (Reason_migrate_parsetree.Ast_411.Parsetree.class_field list) nonterminal
    | N_object_body : (Reason_migrate_parsetree.Ast_411.Parsetree.class_structure) nonterminal
    | N_nonrec_flag : (Reason_migrate_parsetree.Ast_411.Asttypes.rec_flag) nonterminal
    | N_nonempty_list_preceded_CONSTRAINT_constrain__ : ((Reason_migrate_parsetree.Ast_411.Parsetree.core_type *
   Reason_migrate_parsetree.Ast_411.Parsetree.core_type * Warnings.loc)
  list) nonterminal
    | N_nonempty_list_name_tag_ : (string list) nonterminal
    | N_nonempty_list_attributed_ext_constructor_extension_constructor_declaration__ : (Reason_migrate_parsetree.Ast_411.Parsetree.extension_constructor list) nonterminal
    | N_nonempty_list_attributed_ext_constructor_either_extension_constructor_declaration_extension_constructor_rebind___ : (Reason_migrate_parsetree.Ast_411.Parsetree.extension_constructor list) nonterminal
    | N_nonempty_list_as_loc_preceded_QUOTE_ident___ : (string Location.loc list) nonterminal
    | N_nonempty_list_as_loc_attribute__ : (Reason_migrate_parsetree.Ast_411.Parsetree.attribute Location.loc list) nonterminal
    | N_nonempty_list_as_loc_LIDENT__ : (string Location.loc list) nonterminal
    | N_nonempty_list___anonymous_31_ : (string list) nonterminal
    | N_non_labeled_argument_list : (Reason_migrate_parsetree.Ast_411.Parsetree.expression list) nonterminal
    | N_non_arrowed_simple_core_types : (Reason_migrate_parsetree.Ast_411.Parsetree.core_type) nonterminal
    | N_non_arrowed_simple_core_type : (Reason_migrate_parsetree.Ast_411.Parsetree.core_type) nonterminal
    | N_non_arrowed_core_type : (Reason_migrate_parsetree.Ast_411.Parsetree.core_type) nonterminal
    | N_mutable_or_virtual_flags : (Reason_migrate_parsetree.Ast_411.Asttypes.mutable_flag *
  Reason_migrate_parsetree.Ast_411.Asttypes.virtual_flag) nonterminal
    | N_mutable_flag : (Reason_migrate_parsetree.Ast_411.Asttypes.mutable_flag) nonterminal
    | N_mty_longident : (Longident.t) nonterminal
    | N_module_type_signature : (Reason_migrate_parsetree.Ast_411.Parsetree.module_type) nonterminal
    | N_module_type_body_EQUAL_ : (Reason_migrate_parsetree.Ast_411.Parsetree.module_type) nonterminal
    | N_module_type_body_COLON_ : (Reason_migrate_parsetree.Ast_411.Parsetree.module_type) nonterminal
    | N_module_type : (Reason_migrate_parsetree.Ast_411.Parsetree.module_type) nonterminal
    | N_module_parameter : (Reason_migrate_parsetree.Ast_411.Parsetree.functor_parameter Location.loc) nonterminal
    | N_module_expr_structure : (Reason_migrate_parsetree.Ast_411.Parsetree.module_expr) nonterminal
    | N_module_expr_body : (Reason_migrate_parsetree.Ast_411.Parsetree.module_expr) nonterminal
    | N_module_expr : (Reason_migrate_parsetree.Ast_411.Parsetree.module_expr) nonterminal
    | N_module_declaration : (Reason_migrate_parsetree.Ast_411.Parsetree.module_type) nonterminal
    | N_module_complex_expr : (Reason_migrate_parsetree.Ast_411.Parsetree.module_expr) nonterminal
    | N_module_binding_body : (Reason_migrate_parsetree.Ast_411.Parsetree.module_expr) nonterminal
    | N_module_arguments_comma_list : (Reason_migrate_parsetree.Ast_411.Parsetree.module_expr list) nonterminal
    | N_module_arguments : (Reason_migrate_parsetree.Ast_411.Parsetree.module_expr list) nonterminal
    | N_mod_longident : (Longident.t) nonterminal
    | N_mod_ident : (string option) nonterminal
    | N_mod_ext_longident : (Longident.t) nonterminal
    | N_mod_ext_lesslongident : (Longident.t) nonterminal
    | N_mod_ext_less_apply : (Longident.t) nonterminal
    | N_mod_ext_apply : (Longident.t) nonterminal
    | N_method_ : (string Location.loc *
  Reason_migrate_parsetree.Ast_411.Parsetree.class_field_kind) nonterminal
    | N_match_case_seq_expr_ : (Reason_migrate_parsetree.Ast_411.Parsetree.case) nonterminal
    | N_match_case_expr_ : (Reason_migrate_parsetree.Ast_411.Parsetree.case) nonterminal
    | N_lseparated_nonempty_list_aux_SEMI_class_sig_field_ : (Reason_migrate_parsetree.Ast_411.Parsetree.class_type_field list list) nonterminal
    | N_lseparated_nonempty_list_aux_SEMI_class_field_ : (Reason_migrate_parsetree.Ast_411.Parsetree.class_field list list) nonterminal
    | N_lseparated_nonempty_list_aux_COMMA_uncurried_labeled_expr_ : ((Reason_migrate_parsetree.Ast_411.Asttypes.arg_label *
   Reason_migrate_parsetree.Ast_411.Parsetree.expression)
  list) nonterminal
    | N_lseparated_nonempty_list_aux_COMMA_uncurried_arrow_type_parameter_ : (((Reason_migrate_parsetree.Ast_411.Asttypes.arg_label *
    Reason_migrate_parsetree.Ast_411.Parsetree.core_type)
   Location.loc * bool)
  list) nonterminal
    | N_lseparated_nonempty_list_aux_COMMA_type_variable_with_variance_ : ((Reason_migrate_parsetree.Ast_411.Parsetree.core_type *
   Reason_migrate_parsetree.Ast_411.Asttypes.variance)
  list) nonterminal
    | N_lseparated_nonempty_list_aux_COMMA_type_parameter_ : ((Reason_migrate_parsetree.Ast_411.Parsetree.core_type *
   Reason_migrate_parsetree.Ast_411.Asttypes.variance)
  list) nonterminal
    | N_lseparated_nonempty_list_aux_COMMA_string_literal_label_ : (Reason_migrate_parsetree.Ast_411.Parsetree.object_field list) nonterminal
    | N_lseparated_nonempty_list_aux_COMMA_string_literal_expr_maybe_punned_ : ((Longident.t Location.loc *
   Reason_migrate_parsetree.Ast_411.Parsetree.expression)
  list) nonterminal
    | N_lseparated_nonempty_list_aux_COMMA_record_label_declaration_ : (Reason_migrate_parsetree.Ast_411.Parsetree.label_declaration list) nonterminal
    | N_lseparated_nonempty_list_aux_COMMA_protected_type_ : (Reason_migrate_parsetree.Ast_411.Parsetree.core_type list) nonterminal
    | N_lseparated_nonempty_list_aux_COMMA_pattern_optional_constraint_ : (Reason_migrate_parsetree.Ast_411.Parsetree.pattern list) nonterminal
    | N_lseparated_nonempty_list_aux_COMMA_opt_spread_pattern__ : ((Warnings.loc option * Reason_migrate_parsetree.Ast_411.Parsetree.pattern)
  list) nonterminal
    | N_lseparated_nonempty_list_aux_COMMA_opt_spread_lbl_expr__ : ((Warnings.loc option *
   (Longident.t Location.loc *
    Reason_migrate_parsetree.Ast_411.Parsetree.expression))
  list) nonterminal
    | N_lseparated_nonempty_list_aux_COMMA_opt_spread_expr_optional_constraint__ : ((Warnings.loc option *
   Reason_migrate_parsetree.Ast_411.Parsetree.expression)
  list) nonterminal
    | N_lseparated_nonempty_list_aux_COMMA_object_label_declaration_ : (Reason_migrate_parsetree.Ast_411.Parsetree.object_field list) nonterminal
    | N_lseparated_nonempty_list_aux_COMMA_module_parameter_ : (Reason_migrate_parsetree.Ast_411.Parsetree.functor_parameter Location.loc
  list) nonterminal
    | N_lseparated_nonempty_list_aux_COMMA_module_complex_expr_ : (Reason_migrate_parsetree.Ast_411.Parsetree.module_expr list) nonterminal
    | N_lseparated_nonempty_list_aux_COMMA_mod_ext_longident_ : (Longident.t list) nonterminal
    | N_lseparated_nonempty_list_aux_COMMA_labeled_pattern_ : (Reason_parser_def.labelled_parameter Location.loc list) nonterminal
    | N_lseparated_nonempty_list_aux_COMMA_field_expr_ : ((string Location.loc *
   Reason_migrate_parsetree.Ast_411.Parsetree.expression)
  list) nonterminal
    | N_lseparated_nonempty_list_aux_COMMA_expr_optional_constraint_ : (Reason_migrate_parsetree.Ast_411.Parsetree.expression list) nonterminal
    | N_lseparated_nonempty_list_aux_COMMA_expr_ : (Reason_migrate_parsetree.Ast_411.Parsetree.expression list) nonterminal
    | N_lseparated_nonempty_list_aux_COMMA_core_type_ : (Reason_migrate_parsetree.Ast_411.Parsetree.core_type list) nonterminal
    | N_lseparated_nonempty_list_aux_AND_with_constraint_ : (Reason_migrate_parsetree.Ast_411.Parsetree.with_constraint list) nonterminal
    | N_loption_type_parameters_ : (Reason_migrate_parsetree.Ast_411.Parsetree.core_type list) nonterminal
    | N_loption_terminated_pattern_comma_list_option_COMMA___ : (Reason_migrate_parsetree.Ast_411.Parsetree.pattern list) nonterminal
    | N_loption_row_field_list_ : (Reason_migrate_parsetree.Ast_411.Parsetree.row_field list) nonterminal
    | N_loption_preceded_GREATER_nonempty_list_name_tag___ : (string list) nonterminal
    | N_loption_parenthesized_type_variables_with_variance_comma_list__ : ((Reason_migrate_parsetree.Ast_411.Parsetree.core_type *
   Reason_migrate_parsetree.Ast_411.Asttypes.variance)
  list) nonterminal
    | N_loption_parenthesized_class_type_arguments_comma_list__ : (Reason_migrate_parsetree.Ast_411.Parsetree.core_type list) nonterminal
    | N_loption_object_label_declarations_ : (Reason_migrate_parsetree.Ast_411.Parsetree.object_field list) nonterminal
    | N_loption_located_attributes_ : (Reason_migrate_parsetree.Ast_411.Parsetree.attribute Location.loc list) nonterminal
    | N_loption_functor_parameters_ : (Reason_migrate_parsetree.Ast_411.Parsetree.functor_parameter Location.loc
  list) nonterminal
    | N_loption_class_type_parameters_ : ((Reason_migrate_parsetree.Ast_411.Parsetree.core_type *
   Reason_migrate_parsetree.Ast_411.Asttypes.variance)
  list) nonterminal
    | N_longident_type_constraint : (Longident.t Location.loc *
  (Reason_migrate_parsetree.Ast_411.Parsetree.core_type option *
   Reason_migrate_parsetree.Ast_411.Parsetree.core_type option)
  option) nonterminal
    | N_llist_aux_preceded_COMMA_opt_spread_lbl_expr___ : ((Warnings.loc option *
   (Longident.t Location.loc *
    Reason_migrate_parsetree.Ast_411.Parsetree.expression))
  list) nonterminal
    | N_llist_aux_match_case_seq_expr__ : (Reason_migrate_parsetree.Ast_411.Parsetree.case list) nonterminal
    | N_llist_aux_match_case_expr__ : (Reason_migrate_parsetree.Ast_411.Parsetree.case list) nonterminal
    | N_list_simple_expr_no_call_ : (Reason_migrate_parsetree.Ast_411.Parsetree.expression list) nonterminal
    | N_list_bar_row_field_ : (Reason_migrate_parsetree.Ast_411.Parsetree.row_field list) nonterminal
    | N_list_attributed_ext_constructor_extension_constructor_declaration__ : (Reason_migrate_parsetree.Ast_411.Parsetree.extension_constructor list) nonterminal
    | N_list_attributed_ext_constructor_either_extension_constructor_declaration_extension_constructor_rebind___ : (Reason_migrate_parsetree.Ast_411.Parsetree.extension_constructor list) nonterminal
    | N_list_and_module_rec_declaration_ : (Reason_migrate_parsetree.Ast_411.Parsetree.module_declaration list) nonterminal
    | N_list_and_module_bindings_ : (Reason_migrate_parsetree.Ast_411.Parsetree.module_binding list) nonterminal
    | N_list_and_let_binding_ : (Reason_migrate_parsetree.Ast_411.Parsetree.value_binding list) nonterminal
    | N_list_and_class_type_declaration_ : (Reason_migrate_parsetree.OCaml_411.Ast.Parsetree.class_type_declaration
  list) nonterminal
    | N_list_and_class_description_ : (Reason_migrate_parsetree.OCaml_411.Ast.Parsetree.class_description list) nonterminal
    | N_list_and_class_declaration_ : (Reason_migrate_parsetree.OCaml_411.Ast.Parsetree.class_declaration list) nonterminal
    | N_letop_bindings : (Reason_migrate_parsetree.Ast_411.Parsetree.pattern *
  Reason_migrate_parsetree.Ast_411.Parsetree.expression *
  Reason_migrate_parsetree.Ast_411.Parsetree.binding_op list) nonterminal
    | N_letop_binding_body : (Reason_migrate_parsetree.Ast_411.Parsetree.pattern *
  Reason_migrate_parsetree.Ast_411.Parsetree.expression) nonterminal
    | N_let_bindings : (Reason_parser_def.let_bindings) nonterminal
    | N_let_binding_body : (Reason_migrate_parsetree.Ast_411.Parsetree.pattern *
  Reason_migrate_parsetree.Ast_411.Parsetree.expression) nonterminal
    | N_let_binding : (Reason_parser_def.let_bindings) nonterminal
    | N_lbl_pattern : (Longident.t Location.loc *
  Reason_migrate_parsetree.Ast_411.Parsetree.pattern) nonterminal
    | N_labelled_arrow_type_parameter_optional : (Reason_migrate_parsetree.Ast_411.Asttypes.arg_label *
  Reason_migrate_parsetree.Ast_411.Parsetree.core_type) nonterminal
    | N_labeled_pattern_constraint : (string Location.loc -> Reason_migrate_parsetree.Ast_411.Parsetree.pattern) nonterminal
    | N_labeled_pattern : (Reason_parser_def.labelled_parameter Location.loc) nonterminal
    | N_labeled_expr_constraint : (Longident.t Location.loc ->
  Reason_migrate_parsetree.Ast_411.Parsetree.expression) nonterminal
    | N_labeled_expr : (Reason_migrate_parsetree.Ast_411.Asttypes.arg_label *
  Reason_migrate_parsetree.Ast_411.Parsetree.expression) nonterminal
    | N_labeled_arguments : ((Reason_migrate_parsetree.Ast_411.Asttypes.arg_label *
   Reason_migrate_parsetree.Ast_411.Parsetree.expression)
  list) nonterminal
    | N_label_longident : (Longident.t) nonterminal
    | N_jsx_without_leading_less : (Reason_migrate_parsetree.Ast_411.Parsetree.expression) nonterminal
    | N_jsx_start_tag_and_args_without_leading_less : (((Reason_migrate_parsetree.Ast_411.Asttypes.arg_label *
    Reason_migrate_parsetree.Ast_411.Parsetree.expression)
   list ->
   Warnings.loc -> Reason_migrate_parsetree.Ast_411.Parsetree.expression) *
  Longident.t) nonterminal
    | N_jsx_start_tag_and_args : (((Reason_migrate_parsetree.Ast_411.Asttypes.arg_label *
    Reason_migrate_parsetree.Ast_411.Parsetree.expression)
   list ->
   Warnings.loc -> Reason_migrate_parsetree.Ast_411.Parsetree.expression) *
  Longident.t) nonterminal
    | N_jsx_arguments : ((Reason_migrate_parsetree.Ast_411.Asttypes.arg_label *
   Reason_migrate_parsetree.Ast_411.Parsetree.expression)
  list) nonterminal
    | N_jsx : (Reason_migrate_parsetree.Ast_411.Parsetree.expression) nonterminal
    | N_item_extension_sugar : (Reason_migrate_parsetree__Migrate_parsetree_versions.OCaml_411.Ast.Ast_helper.attrs *
  string Location.loc) nonterminal
    | N_item_extension : (Reason_migrate_parsetree.OCaml_411.Ast.Parsetree.extension) nonterminal
    | N_interface : (Reason_migrate_parsetree.Ast_411.Parsetree.signature) nonterminal
    | N_implementation : (Reason_migrate_parsetree.Ast_411.Parsetree.structure) nonterminal
    | N_ident : (string) nonterminal
    | N_greater_spread : (string) nonterminal
    | N_generalized_constructor_arguments : (Reason_migrate_parsetree.Ast_411.Parsetree.constructor_arguments *
  Reason_migrate_parsetree.Ast_411.Parsetree.core_type option) nonterminal
    | N_functor_parameters : (Reason_migrate_parsetree.Ast_411.Parsetree.functor_parameter Location.loc
  list) nonterminal
    | N_fun_def_EQUALGREATER_non_arrowed_core_type_ : (Reason_migrate_parsetree.Ast_411.Parsetree.expression) nonterminal
    | N_fun_def_EQUAL_core_type_ : (Reason_migrate_parsetree.Ast_411.Parsetree.expression) nonterminal
    | N_field_expr : (string Location.loc * Reason_migrate_parsetree.Ast_411.Parsetree.expression) nonterminal
    | N_extension_constructor_rebind : (Reason_migrate_parsetree.Ast_411.Parsetree.extension_constructor) nonterminal
    | N_extension_constructor_declaration : (Reason_migrate_parsetree.Ast_411.Parsetree.extension_constructor) nonterminal
    | N_extension : (Reason_migrate_parsetree.OCaml_411.Ast.Parsetree.extension) nonterminal
    | N_expr_optional_constraint : (Reason_migrate_parsetree.Ast_411.Parsetree.expression) nonterminal
    | N_expr_list : (Reason_migrate_parsetree.Ast_411.Parsetree.expression list) nonterminal
    | N_expr_comma_seq_extension : (Reason_migrate_parsetree.Ast_411.Parsetree.expression list *
  Reason_migrate_parsetree.Ast_411.Parsetree.expression option) nonterminal
    | N_expr : (Reason_migrate_parsetree.Ast_411.Parsetree.expression) nonterminal
    | N_es6_parameters : (Reason_parser_def.labelled_parameter Location.loc list * bool) nonterminal
    | N_embedded_private_flag_ : (Reason_migrate_parsetree.Ast_411.Asttypes.private_flag) nonterminal
    | N_embedded___anonymous_39_ : (Reason_migrate_parsetree.Ast_411.Parsetree.directive_argument_desc option) nonterminal
    | N_embedded___anonymous_32_ : (Reason_migrate_parsetree.Ast_411.Parsetree.core_type *
  Reason_migrate_parsetree.Ast_411.Asttypes.variance) nonterminal
    | N_embedded___anonymous_1_ : (Reason_migrate_parsetree.Ast_411.Parsetree.toplevel_phrase list) nonterminal
    | N_embedded___anonymous_0_ : (Reason_migrate_parsetree.Ast_411.Parsetree.toplevel_phrase) nonterminal
    | N_either_preceded_EQUALGREATER_expr__braced_expr_ : (Reason_migrate_parsetree.Ast_411.Parsetree.expression) nonterminal
    | N_either_preceded_EQUAL_expr__braced_expr_ : (Reason_migrate_parsetree.Ast_411.Parsetree.expression) nonterminal
    | N_either_preceded_EQUAL_class_instance_type__class_type_body_ : (Reason_migrate_parsetree.Ast_411.Parsetree.class_type) nonterminal
    | N_either_preceded_EQUAL_class_expr__class_body_expr_ : (Reason_migrate_parsetree.Ast_411.Parsetree.class_expr) nonterminal
    | N_either_parenthesized_longident_type_constraint__longident_type_constraint_ : (Longident.t Location.loc *
  (Reason_migrate_parsetree.Ast_411.Parsetree.core_type option *
   Reason_migrate_parsetree.Ast_411.Parsetree.core_type option)
  option) nonterminal
    | N_either_extension_constructor_declaration_extension_constructor_rebind_ : (Reason_migrate_parsetree.Ast_411.Parsetree.extension_constructor) nonterminal
    | N_either_constructor_declaration_bar_constructor_declaration_ : (Reason_migrate_parsetree.Ast_411.Parsetree.constructor_declaration) nonterminal
    | N_either___anonymous_11___anonymous_12_ : (Reason_migrate_parsetree.Ast_411.Asttypes.private_flag) nonterminal
    | N_either_ES6_FUN_FUN_ : (unit) nonterminal
    | N_direction_flag : (Reason_migrate_parsetree.Ast_411.Asttypes.direction_flag) nonterminal
    | N_core_type2 : (Reason_migrate_parsetree.Ast_411.Parsetree.core_type) nonterminal
    | N_core_type : (Reason_migrate_parsetree.Ast_411.Parsetree.core_type) nonterminal
    | N_constructor_declarations_aux : (Reason_migrate_parsetree.Ast_411.Parsetree.constructor_declaration list *
  (Reason_migrate_parsetree.Ast_411.Parsetree.core_type *
   Reason_migrate_parsetree.Ast_411.Parsetree.core_type * Warnings.loc)
  list * Lexing.position *
  Reason_migrate_parsetree.Ast_411.Parsetree.type_declaration list) nonterminal
    | N_constructor_declarations : (Reason_migrate_parsetree.Ast_411.Parsetree.constructor_declaration list *
  (Reason_migrate_parsetree.Ast_411.Parsetree.core_type *
   Reason_migrate_parsetree.Ast_411.Parsetree.core_type * Warnings.loc)
  list * Lexing.position *
  Reason_migrate_parsetree.Ast_411.Parsetree.type_declaration list) nonterminal
    | N_constructor_declaration : (Reason_migrate_parsetree.Ast_411.Parsetree.constructor_declaration) nonterminal
    | N_constructor_arguments_comma_list : (Reason_migrate_parsetree.Ast_411.Parsetree.core_type list) nonterminal
    | N_constructor_arguments : (Reason_migrate_parsetree.Ast_411.Parsetree.constructor_arguments) nonterminal
    | N_constrain_field : (Reason_migrate_parsetree.Ast_411.Parsetree.core_type *
  Reason_migrate_parsetree.Ast_411.Parsetree.core_type) nonterminal
    | N_constrain : (Reason_migrate_parsetree.Ast_411.Parsetree.core_type *
  Reason_migrate_parsetree.Ast_411.Parsetree.core_type * Warnings.loc) nonterminal
    | N_constr_longident : (Longident.t) nonterminal
    | N_constant : (Reason_migrate_parsetree__Migrate_parsetree_versions.OCaml_411.Ast.Ast_helper.attrs *
  Reason_migrate_parsetree.Ast_411.Parsetree.constant) nonterminal
    | N_clty_longident : (Longident.t) nonterminal
    | N_class_type_declarations : (Reason_migrate_parsetree.OCaml_411.Ast.Parsetree.class_type_declaration
  list) nonterminal
    | N_class_type_declaration_details : (Reason_migrate_parsetree__Migrate_parsetree_versions.OCaml_411.Ast.Ast_helper.str *
  Reason_migrate_parsetree.Ast_411.Parsetree.class_type *
  Reason_migrate_parsetree.Ast_411.Asttypes.virtual_flag *
  (Reason_migrate_parsetree.Ast_411.Parsetree.core_type *
   Reason_migrate_parsetree.Ast_411.Asttypes.variance)
  list) nonterminal
    | N_class_type_body : (Reason_migrate_parsetree.Ast_411.Parsetree.class_type) nonterminal
    | N_class_type_arguments_comma_list : (Reason_migrate_parsetree.Ast_411.Parsetree.core_type list) nonterminal
    | N_class_simple_expr : (Reason_migrate_parsetree.Ast_411.Parsetree.class_expr) nonterminal
    | N_class_sig_field : (Reason_migrate_parsetree.Ast_411.Parsetree.class_type_field list) nonterminal
    | N_class_sig_body_fields : (Reason_migrate_parsetree.Ast_411.Parsetree.class_type_field list) nonterminal
    | N_class_sig_body_cty : (Reason_migrate_parsetree.Ast_411.Parsetree.class_type_desc) nonterminal
    | N_class_sig_body : (Reason_migrate_parsetree.Ast_411.Parsetree.class_signature) nonterminal
    | N_class_self_type : (Reason_migrate_parsetree.Ast_411.Parsetree.core_type) nonterminal
    | N_class_self_expr : (Reason_migrate_parsetree.Ast_411.Parsetree.pattern) nonterminal
    | N_class_longident : (Longident.t) nonterminal
    | N_class_instance_type : (Reason_migrate_parsetree.Ast_411.Parsetree.class_type) nonterminal
    | N_class_field : (Reason_migrate_parsetree.Ast_411.Parsetree.class_field list) nonterminal
    | N_class_expr_lets_and_rest : (Reason_migrate_parsetree.Ast_411.Parsetree.class_expr) nonterminal
    | N_class_expr : (Reason_migrate_parsetree.Ast_411.Parsetree.class_expr) nonterminal
    | N_class_descriptions : (Reason_migrate_parsetree.OCaml_411.Ast.Parsetree.class_description list) nonterminal
    | N_class_description_details : (Reason_migrate_parsetree__Migrate_parsetree_versions.OCaml_411.Ast.Ast_helper.str *
  Reason_migrate_parsetree.Ast_411.Parsetree.class_type *
  Reason_migrate_parsetree.Ast_411.Asttypes.virtual_flag *
  (Reason_migrate_parsetree.Ast_411.Parsetree.core_type *
   Reason_migrate_parsetree.Ast_411.Asttypes.variance)
  list) nonterminal
    | N_class_declaration_details : (Reason_migrate_parsetree__Migrate_parsetree_versions.OCaml_411.Ast.Ast_helper.str *
  Reason_migrate_parsetree.Ast_411.Parsetree.class_expr *
  Reason_migrate_parsetree.Ast_411.Asttypes.virtual_flag *
  (Reason_migrate_parsetree.Ast_411.Parsetree.core_type *
   Reason_migrate_parsetree.Ast_411.Asttypes.variance)
  list) nonterminal
    | N_class_declaration_body : (Reason_migrate_parsetree.Ast_411.Parsetree.class_expr) nonterminal
    | N_class_constructor_type : (Reason_migrate_parsetree.Ast_411.Parsetree.class_type) nonterminal
    | N_braced_expr : (Reason_migrate_parsetree.Ast_411.Parsetree.expression) nonterminal
    | N_boption_AMPERSAND_ : (bool) nonterminal
    | N_basic_core_type : (Reason_migrate_parsetree.Ast_411.Parsetree.core_type) nonterminal
    | N_bar_row_field : (Reason_migrate_parsetree.Ast_411.Parsetree.row_field) nonterminal
    | N_bar_constructor_declaration : (Reason_migrate_parsetree.Ast_411.Parsetree.constructor_declaration) nonterminal
    | N_attributed_ext_constructors_extension_constructor_declaration_ : (Reason_migrate_parsetree.Ast_411.Parsetree.extension_constructor list) nonterminal
    | N_attributed_ext_constructors_either_extension_constructor_declaration_extension_constructor_rebind__ : (Reason_migrate_parsetree.Ast_411.Parsetree.extension_constructor list) nonterminal
    | N_attribute : (Reason_migrate_parsetree.Ast_411.Parsetree.attribute) nonterminal
    | N_attr_id : (string Location.loc) nonterminal
    | N_arrowed_simple_core_type : (Reason_migrate_parsetree.Ast_411.Parsetree.core_type) nonterminal
    | N_arrow_type_parameters : (((Reason_migrate_parsetree.Ast_411.Asttypes.arg_label *
    Reason_migrate_parsetree.Ast_411.Parsetree.core_type)
   Location.loc * bool)
  list) nonterminal
    | N_arrow_type_parameter : (Reason_migrate_parsetree.Ast_411.Asttypes.arg_label *
  Reason_migrate_parsetree.Ast_411.Parsetree.core_type) nonterminal
    | N_and_type_subst_declaration : (Reason_migrate_parsetree.Ast_411.Parsetree.type_declaration list) nonterminal
    | N_and_type_declaration : (Reason_migrate_parsetree.Ast_411.Parsetree.type_declaration list) nonterminal
    | N_and_module_rec_declaration : (Reason_migrate_parsetree.Ast_411.Parsetree.module_declaration) nonterminal
    | N_and_module_bindings : (Reason_migrate_parsetree.Ast_411.Parsetree.module_binding) nonterminal
    | N_and_class_type_declaration : (Reason_migrate_parsetree.OCaml_411.Ast.Parsetree.class_type_declaration) nonterminal
    | N_and_class_description : (Reason_migrate_parsetree.OCaml_411.Ast.Parsetree.class_description) nonterminal
    | N_and_class_declaration : (Reason_migrate_parsetree.Ast_411.Parsetree.class_expr
  Reason_migrate_parsetree.Ast_411.Parsetree.class_infos) nonterminal
    | N__lbl_pattern_list : ((Warnings.loc option *
   (Longident.t Location.loc *
    Reason_migrate_parsetree.Ast_411.Parsetree.pattern))
  list * Reason_migrate_parsetree.Ast_411.Asttypes.closed_flag) nonterminal
  
  (* The inspection API. *)
  
  include MenhirLib.IncrementalEngine.INSPECTION
    with type 'a lr1state := 'a lr1state
    with type production := production
    with type 'a terminal := 'a terminal
    with type 'a nonterminal := 'a nonterminal
    with type 'a env := 'a env
  
end

(* The entry point(s) to the incremental API. *)

module Incremental : sig
  
  val use_file: Lexing.position -> (Reason_migrate_parsetree.Ast_411.Parsetree.toplevel_phrase list) MenhirInterpreter.checkpoint
  
  val toplevel_phrase: Lexing.position -> (Reason_migrate_parsetree.Ast_411.Parsetree.toplevel_phrase) MenhirInterpreter.checkpoint
  
  val parse_pattern: Lexing.position -> (Reason_migrate_parsetree.Ast_411.Parsetree.pattern) MenhirInterpreter.checkpoint
  
  val parse_expression: Lexing.position -> (Reason_migrate_parsetree.Ast_411.Parsetree.expression) MenhirInterpreter.checkpoint
  
  val parse_core_type: Lexing.position -> (Reason_migrate_parsetree.Ast_411.Parsetree.core_type) MenhirInterpreter.checkpoint
  
  val interface: Lexing.position -> (Reason_migrate_parsetree.Ast_411.Parsetree.signature) MenhirInterpreter.checkpoint
  
  val implementation: Lexing.position -> (Reason_migrate_parsetree.Ast_411.Parsetree.structure) MenhirInterpreter.checkpoint
  
end
